********************************************************************************
*** Analysen zu Buchbeitrag "Was macht den Unterschied? Ein Vergleich von    *** 
*** von Bildungsaufsteigern und Nichtaufsteigern"                            ***
***                                                                          ***
*** Deskriptive Analysen                                                     ***
*** Steffen Schindler, 01.03.2019                                            *** 
********************************************************************************


********************************************************************************
*** Datensatz laden ************************************************************
********************************************************************************

cd "$save"
use "complete_g.dta", clear


********************************************************************************
*** Analysenspezifische Recodes ************************************************
********************************************************************************

*** niedriges Einkommen binär
recode eink_k (1=1 "<2000") (2 3=0 ">=2000") (else=.), into(eink_bi)

*** Signifikante Personen binär kodieren: jeweils mehr als die Hälfte
foreach var of varlist sig_verw sig_freu sig_freuf{
   recode `var' (1/3=0) (4/5=1), into(`var'_bi)
   }
foreach var of varlist sig_verws sig_freus{
   recode `var' (1/4=0) (5/7=1), into(`var'_bi)
   }
   
   
********************************************************************************
*** Globals ********************************************************************
********************************************************************************

*** Gewicht ***
global gew=w_t7  // w_t7


********************************************************************************
*** Beschreibung der Verteilung Bildung der Eltern - Schulform in W7 ***********
********************************************************************************

*** Kreutabelle, ungewichtet ***
tab bilelt schulform,ro

*** Kreutabelle, gewichtet ***
tab bilelt schulform [aw=$gew],ro


********************************************************************************
*** Anzahl gültige Werte auf Prädiktoren ***************************************
********************************************************************************

egen nonmiss=rownonmiss(eink_k allein abikost_l ///
                        buch kultbesitz kultpart kultkap haustaet buchkenn ///
						monitor monitor_k geschwister eltschul ausaktiv ///
						sig_verw_bi sig_freu_bi sig_freuf_bi sig_verws_bi sig_freus_bi ///
						aspabi wskabi ///
						klscore kl_kompscore kl_prozmeta migant kl_esprache elthoschu kl_eltho ///
						b5_* lernfreu anstreng kompscore prozmeta note)
gen miss=38-nonmiss
lab var nonmiss "Anzahl Prädiktoren mit gültigen Werten (von 38)"
lab var miss "Anzahl Prädiktoren mit fehlenden Werten (von 38)"
tab bildauf nonmiss
tab bildauf miss
recode miss (0=0 "0") (1=1 "1") (2=2 "2") (3=3 "3") (4=4 "4") (5/10=5 "5-10") (11/20=6 "11-20") (21/30=7 "21-30") (31/38=8 "31-38"), into(miss_k)
lab var miss_k "Anzahl Prädiktoren mit fehlenden Werten (von 38, Kategorien)"
tab bildauf miss_k 


********************************************************************************
*** Ökonomische Ressourcen *****************************************************
********************************************************************************

*** Haushaltseinkommen ***
tab bildauf_d eink_k [aw=$gew], row

*** Alleinerziehend ***
tab bildauf_d allein [aw=$gew], row

*** Finanzielle Belastung durch Abitur
tab bildauf_d abikost_l [aw=$gew], row // Kosten tragen fällt leicht
tab bildauf_d abikost_s [aw=$gew], row // Kosten tragen fällt schwer


********************************************************************************
*** Kulturelle Ressourcen ******************************************************
********************************************************************************

*** Anzahl Bücher ***
recode buch (1/3=0 "<100") (4/6=1 ">100"), into(buch_d)
tab bildauf_d buch_d [aw=$gew], row

*** Besitz kultureller Güter ***
tab bildauf_d [aw=$gew], sum(kultbesitz)

*** Partizipation an Hochkultur
tab bildauf_d [aw=$gew], sum(kultpart)

*** Score kulturelles Kapital
tab bildauf_d [aw=$gew], sum(kultkap)

*** schulnahe Tätigkeiten zu Hause ***
tab bildauf_d [aw=$gew], sum(haustaet)

*** Kenntnisse Kinderbücher ***
tab bildauf_d [aw=$gew], sum(buchkenn)


********************************************************************************
*** Soziale Ressourcen *********************************************************
********************************************************************************

*** Parental Monitoring (Elternfragebogen) ***
tab bildauf_d [aw=$gew], sum(monitor)

*** Parental Monitoring (Schülerfragebogen) ***
tab bildauf_d [aw=$gew], sum(monitor_k)

*** Anzahl Geschwister im Haushalt ***
tab bildauf_d [aw=$gew], sum(geschwister)

*** Schulische Einbindung der Eltern ***
tab bildauf_d [aw=$gew], sum(eltschul)

*** außerhäusliche Aktivitäten ***
tab bildauf_d [aw=$gew], sum(ausaktiv)

*** signifikante Personen: Verwandte interessieren sich ***
tab bildauf_d sig_verw_bi [aw=$gew], row

*** signifikante Personen: Freunde interessieren sich ***
tab bildauf_d sig_freu_bi [aw=$gew], row

*** signifikante Personen: Freunde erwarten Förderung des Kindes ***
tab bildauf_d sig_freuf_bi [aw=$gew], row

*** signifikante Personen: Anteil Verwandte mit Studium ***
tab bildauf_d sig_verws_bi [aw=$gew], row

*** signifikante Personen: Anteil Freunde mit Studium ***
tab bildauf_d sig_freus_bi [aw=$gew], row
   


********************************************************************************
*** Bildungsaspirationen und Risikowahrnehmung *********************************
********************************************************************************

*** Aspiration für Abitur ***
tab bildauf_d aspabi [aw=$gew], row

*** Einschätzung Wahrscheinlichkeit Abitur zu erreichen ***
tab bildauf_d wskabi [aw=$gew], row


********************************************************************************
*** Lernkontexte ***************************************************************
********************************************************************************

*** Lehrerfragebogen ***********************************************************

*** Score Leistungsstand Schulklasse (Lehrereinschätzung) ***
tab bildauf_d [aw=$gew], sum(klscore)

*** Anteil SchülerInnen mit Migrationshintergrund (Lehrereinschätzung) ***
tab bildauf_d migant [aw=$gew], row

*** Anteil SchülerInnen mit hoher sozialer Schicht (Lehrereinschätzung) ***
tab bildauf_d hoschi [aw=$gew], row

*** Anteil SchülerInnen mit niedriger sozialer Schicht (Lehrereinschätzung) ***
tab bildauf_d nischi [aw=$gew], row

*** Anteil SchülerInnen mit Eltern mit Hochschulabschluss (Lehrereinschätzung) ***
tab bildauf_d elthoschu [aw=$gew], row


*** generiert aus Individualdaten **********************************************

*** kumulierter Kompetenzscore Klasse (generiert) ***
tab bildauf_d [aw=$gew], sum(kl_kompscore)

*** prozedurale Metakognition Klasse (generiert) ***
tab bildauf_d [aw=$gew], sum(kl_prozmeta)

*** Anteil Herkunftssprache Eltern nicht deutsch (generiert) ***
tab bildauf_d [aw=$gew], sum(kl_esprache)

*** Anteil Eltern mit Hochschulabschluss (generiert) ***
tab bildauf_d [aw=$gew], sum(kl_eltho)

*** Anteil Eltern mit Aspiration für Abitur (generiert) ***
tab bildauf_d [aw=$gew], sum(kl_aspabi)


********************************************************************************
*** Persönlichkeitsmerkmale ****************************************************
********************************************************************************

*** Big Five ***
tab bildauf_d [aw=$gew], sum(b5_neuro)
tab bildauf_d [aw=$gew], sum(b5_offen)
tab bildauf_d [aw=$gew], sum(b5_vertr)
tab bildauf_d [aw=$gew], sum(b5_gewis)
tab bildauf_d [aw=$gew], sum(b5_extra)
    
*** Lernfreude ***
tab bildauf_d [aw=$gew], sum(lernfreu)
 
*** Anstrengungsbereitschaft ***
tab bildauf_d [aw=$gew], sum(anstreng)


********************************************************************************
*** Kompetenzen ****************************************************************
********************************************************************************

*** Score kumulative Kompetenzen ***
tab bildauf_d [aw=$gew], sum(kompscore)

*** Prozedurale Metakognition ***
tab bildauf_d [aw=$gew], sum(prozmeta)


********************************************************************************
*** Schulnoten *****************************************************************
********************************************************************************

*** Note des letzen Jahreszeugnis (Ende Grundschule, W7) ***
tab bildauf_d [aw=$gew], sum(note)












